# MalwareReportObject


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**verdict** | **str** | Detection service verdict such as \&quot;malicious\&quot; or \&quot;benign\&quot; | [optional] 

## Example

```python
from aisecurity.generated_openapi_client.models.malware_report_object import MalwareReportObject

# TODO update the JSON string below
json = "{}"
# create an instance of MalwareReportObject from a JSON string
malware_report_object_instance = MalwareReportObject.from_json(json)
# print the JSON string representation of the object
print(MalwareReportObject.to_json())

# convert the object into a dict
malware_report_object_dict = malware_report_object_instance.to_dict()
# create an instance of MalwareReportObject from a dict
malware_report_object_from_dict = MalwareReportObject.from_dict(malware_report_object_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


